from setuptools import setup

setup(
    name='wordview',
    version='0.0.1',
    description='',
    long_description='',
    url='',
    author='Meghdad Farahmand',
    author_email='meghdad.farahmand@gmail.com',
    packages=[],
    classifiers=['Development Status :: 1 - Planning'],
)
